@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-10-13'; # DATE
-our $VERSION = '1.026'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '1.027'; # VERSION
 
 1;
 # ABSTRACT: A benchmark framework
@@ -18,7 +18,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 1.026 of Bencher (from Perl distribution Bencher), released on 2016-10-13.
+This document describes version 1.027 of Bencher (from Perl distribution Bencher), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -187,6 +187,22 @@ groups of participants having the same tags.
 
 =item * modules (array of str)
 
+These are modules that are to be benchmarked. When running the benchmark
+scenario, these modules will be require'd first, so you don't have to require
+them again manually in your code/code template.
+
+=item * helper_modules (array of str)
+
+These are helper modules that are required when running the participant code,
+but are not the main subject to be benchmarked. They will also be require'd when
+running the benchmark scenario so you don't have to require them manually in
+your code/code template.
+
+The difference with the C<modules> property is: the modules specified in
+C<modules> should be specified as phase=x_benchmarks, rel=x_benchmarked
+prerequisites while modules specified in C<helper_modules> should not. But all
+modules can be specified as phase=x_benchmarks, rel=requires prerequisites.
+
 =item * function (str)
 
 =item * fcall_template (str)
@@ -605,7 +621,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
